FlutterAudioTagger class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
editTags(
Tag tag, String path) → Future< AudioFileData> -
editTagsAndArtwork(
Tag tag, String path) → Future< AudioFileData> -
getAllTags(
String path) → Future< Tag?> -
getArtWork(
String path) → Future< Uint8List?> -
getPlatformVersion(
) → Future< String?> -
getTags(
String path) → Future< Map?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setArtWork(
Uint8List? imageData, String path) → Future< AudioFileData> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- platform → const MethodChannel